argument

package
v0.0.0-...-3cc556f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2026 License: AGPL-3.0 Imports: 2 Imported by: 0

Documentation

Rendered for windows/amd64

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Erase

func Erase(id uint32) bool

Erase is used to erase argument by id.

func EraseAll

func EraseAll()

EraseAll is used to erase all arguments.

func GetPointer

func GetPointer(id uint32) (uintptr, uint32, bool)

GetPointer is used to get argument pointer by id.

func GetValue

func GetValue(id uint32) ([]byte, bool)

GetValue is used to get argument value by id.

Types

This section is empty.

Jump to