storage

package
v0.0.0-...-3cc556f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Rendered for windows/amd64

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Delete

func Delete(id int) error

Delete is used to delete value in in-memory storage by id.

func DeleteAll

func DeleteAll() error

DeleteAll is used to delete all values in in-memory storage.

func GetPointer

func GetPointer(id int) (uintptr, uint32, error)

GetPointer is used to get value pointer from in-memory storage by id.

func GetValue

func GetValue(id int) ([]byte, error)

GetValue is used to get value from in-memory storage by id.

func SetValue

func SetValue(id int, value []byte) error

SetValue is used to store value to in-memory storage by id.

Types

This section is empty.

Jump to