package
Version:
v0.0.0-...-3cc556f
Opens a new window with list of versions in this module.
Published: Mar 17, 2026
License: AGPL-3.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Rendered for windows/amd64
type Status struct {
IsEnabled bool `json:"is_enabled"`
NumNormal int64 `json:"num_normal"`
NumRecover int64 `json:"num_recover"`
NumPanic int64 `json:"num_panic"`
}
Status contains sysmon status.
GetStatus is used to get sysmon status.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.