Documentation
¶
Rendered for windows/amd64
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeleteAll ¶
func DeleteAll() error
DeleteAll is used to delete all values in in-memory storage.
func GetPointer ¶
GetPointer is used to get value pointer from in-memory storage by id.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.